0.9.9 API documentation: matrix_double2x4_precision.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

Typedefs
matrix_double2x4_precision.hpp File Reference

Core features More...

Go to the source code of this file.

## Typedefs
typedef mat< 2, 4, double, highp > | highp_dmat2x4
| 2 columns of 4 components matrix of double-precision floating-point numbers using medium precision arithmetic in term of ULPs. More...
typedef mat< 2, 4, double, lowp > | lowp_dmat2x4
| 2 columns of 4 components matrix of double-precision floating-point numbers using low precision arithmetic in term of ULPs. More...
typedef mat< 2, 4, double, mediump > | mediump_dmat2x4
| 2 columns of 4 components matrix of double-precision floating-point numbers using medium precision arithmetic in term of ULPs. More...

## Detailed Description

Core features

Definition in file matrix_double2x4_precision.hpp.